/**
 * Copyright 2019, OpenCensus Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Measure, Stats } from '@opencensus/core';
/**
 * {@link Measure} for the client-side total bytes sent in request body (not
 * including headers). This is uncompressed bytes.
 */
export declare const HTTP_CLIENT_SENT_BYTES: Measure;
/**
 * {@link Measure} for the client-side total bytes received in response
 * bodies (not including headers but including error responses with bodies).
 * Should be measured from actual bytes received and read, not the value of
 * the Content-Length header. This is uncompressed bytes. Responses with no
 * body should record 0 for this value.
 */
export declare const HTTP_CLIENT_RECEIVED_BYTES: Measure;
/**
 * {@link Measure} for the client-side time between first byte of request
 * headers sent to last byte of response received, or terminal error.
 */
export declare const HTTP_CLIENT_ROUNDTRIP_LATENCY: Measure;
/**
 * {@link Measure} for the server-side total bytes received in request body
 * (not including headers). This is uncompressed bytes.
 */
export declare const HTTP_SERVER_RECEIVED_BYTES: Measure;
/**
 * {@link Measure} for the server-side total bytes sent in response bodies
 * (not including headers but including error responses with bodies). Should
 * be measured from actual bytes written and sent, not the value of the
 * Content-Length header. This is uncompressed bytes. Responses with no
 * body should record 0 for this value.
 */
export declare const HTTP_SERVER_SENT_BYTES: Measure;
/**
 * {@link Measure} for the server-side time between first byte of request
 * headers received to last byte of response sent, or terminal error.
 */
export declare const HTTP_SERVER_LATENCY: Measure;
/** {@link TagKey} for the value of the client-side HTTP host header. */
export declare const HTTP_CLIENT_HOST: {
    name: string;
};
/** {@link TagKey} for the value of the server-side HTTP host header. */
export declare const HTTP_SERVER_HOST: {
    name: string;
};
/**
 * {@link TagKey} for the numeric client-side HTTP response status code (e.g.
 * 200, 404, 500). If a transport error occurred and no status code was read,
 * use "error" as the {@code TagValue}.
 */
export declare const HTTP_CLIENT_STATUS: {
    name: string;
};
/**
 * {@link TagKey} for the numeric server-side HTTP response status code (e.g.
 * 200, 404, 500). If a transport error occurred and no status code was written
 * use "error" as the {@code TagValue}.
 */
export declare const HTTP_SERVER_STATUS: {
    name: string;
};
/**
 * {@link TagKey} for the client-side URL path (not including query string) in
 * the request.
 */
export declare const HTTP_CLIENT_PATH: {
    name: string;
};
/**
 * {@link TagKey} for the server-side URL path (not including query string) in
 * the request.
 */
export declare const HTTP_SERVER_PATH: {
    name: string;
};
/**
 * {@link TagKey} for the client-side HTTP method of the request, capitalized
 * (GET, POST, etc.).
 */
export declare const HTTP_CLIENT_METHOD: {
    name: string;
};
/**
 * {@link TagKey} for the server-side HTTP method of the request, capitalized
 * (GET, POST, etc.).
 */
export declare const HTTP_SERVER_METHOD: {
    name: string;
};
/**
 * {@link TagKey} for the server-side logical route, a pattern that matched the
 * URL, of a handler that processed the request.
 */
export declare const HTTP_SERVER_ROUTE: {
    name: string;
};
/** Register all default views. */
export declare function registerAllViews(globalStats: Stats): void;
/** Register all default client views. */
export declare function registerAllClientViews(globalStats: Stats): void;
/** Register all default server views. */
export declare function registerAllServerViews(globalStats: Stats): void;
